@@ -2,7 +2,7 @@
     Smb4K's container class for information about a host.
                              -------------------
     begin                : Sa Jan 26 2008
-    copyright            : (C) 2008-2016 by Alexander Reinholdt
+    copyright            : (C) 2008-2017 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -351,3 +351,29 @@ void Smb4KHost::setAuthInfo(Smb4KAuthInfo *authInfo)
   d->url.setPassword(authInfo->password());
 }
 
+
+void Smb4KHost::update(Smb4KHost* host)
+{
+  if (QString::compare(workgroupName(), host->workgroupName()) == 0 &&
+      QString::compare(hostName(), host->hostName()) == 0)
+  {
+    setURL(host->url());
+    setComment(host->comment());
+    setIsMasterBrowser(host->isMasterBrowser());
+    
+    // Do not kill the already discovered IP address
+    if (!hasIP() && host->hasIP())
+    {
+      setIP(host->ip());
+    }
+    else
+    {
+      // Do nothing
+    }    
+  }
+  else
+  {
+    // Do nothing
+  }
+}
+
