@@ -3,7 +3,7 @@
     network neighborhood
                              -------------------
     begin                : So Mai 22 2011
-    copyright            : (C) 2011-2016 by Alexander Reinholdt
+    copyright            : (C) 2011-2018 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -89,38 +89,11 @@ class Q_DECL_EXPORT Smb4KScanner : public KCompositeJob
      */
     bool isRunning();
 
-    /**
-     * This function tests whether a process @p process is running. If you also
-     * define the network item, you can test if a certain process is running.
-     *
-     * @param process         The group of processes
-     *
-     * @param item            The network item for a more fine grained testing
-     */
-    bool isRunning(Smb4KGlobal::Process process,
-                    Smb4KBasicNetworkItem *item = NULL);
-
     /**
      * This function aborts all scan jobs at once.
      */
     void abortAll();
 
-    /**
-     * This function aborts a scan jobs that match the combination
-     * of arguments passed. The network item entry may be NULL, the 
-     * process must always be defined.
-     *
-     * The @p item argument can be used to specifically define one single
-     * process to be killed. If you only define @p process, a whole group
-     * of processes is going to be killed.
-     *
-     * @param process         The group of processes that are to be killed
-     *
-     * @param item            The network item for a more fine grained killing
-     */
-    void abort(Smb4KGlobal::Process process,
-                Smb4KBasicNetworkItem *item = NULL);
-
     /**
      * This function starts the composite job
      */
@@ -143,8 +116,7 @@ class Q_DECL_EXPORT Smb4KScanner : public KCompositeJob
      *
      * @param parent          The parent widget
      */
-    void lookupDomainMembers(Smb4KWorkgroup *workgroup,
-                              QWidget *parent = 0);
+    void lookupDomainMembers(WorkgroupPtr workgroup, QWidget *parent = 0);
 
     /**
      * This function looks up all shared resources a certain 
@@ -154,8 +126,7 @@ class Q_DECL_EXPORT Smb4KScanner : public KCompositeJob
      * 
      * @param parent          The parent widget
      */
-    void lookupShares(Smb4KHost *host,
-                       QWidget *parent = 0);
+    void lookupShares(HostPtr host, QWidget *parent = 0);
     
   protected:
     /**
@@ -175,8 +146,7 @@ class Q_DECL_EXPORT Smb4KScanner : public KCompositeJob
      *
      * @param process       The process that is used
      */
-    void aboutToStart(Smb4KBasicNetworkItem *item,
-                       int process);
+    void aboutToStart(const NetworkItemPtr &item, int process);
 
     /**
      * This signal is emitted when a scan process has finished. It passes the
@@ -189,46 +159,35 @@ class Q_DECL_EXPORT Smb4KScanner : public KCompositeJob
      *
      * @param process       The process that was used
      */
-    void finished(Smb4KBasicNetworkItem *item,
-                   int process);
+    void finished(const NetworkItemPtr &item, int process);
 
     /**
-     * This signal emits the list of workgroups that were discovered.
-     *
-     * @param workgroups   The list of workgroups
+     * This signal is emitted when the list of workgroups was updated/changed.
      */
-    void workgroups(const QList<Smb4KWorkgroup *> &workgroups);
+    void workgroups();
 
     /**
-     * This signal emits the list of hosts that were discovered.
+     * This signal is emitted when the list of members of the workgroup @p workgroup 
+     * was discovered.
      *
-     * @param workgroup   The workgroup that was scanned. This argument
-     *                    is NULL in case several workgroups are present
-     *                    in the hosts list.
-     *
-     * @param hosts       The list of hosts
+     * @param workgroup   The workgroup that was scanned
      */
-    void hosts(Smb4KWorkgroup *workgroup,
-                const QList<Smb4KHost *> &hosts);
+    void hosts(const WorkgroupPtr &workgroup);
     
     /**
-     * This signal is emitted when the list of shares are certain host 
-     * offers has been acquired.
+     * This signal is emitted when the list of shares a certain host @p host offers 
+     * has been acquired.
      * 
      * @param host        The host that was queried
-     * 
-     * @param shares      The list of shares belonging to @p host
      */
-    void shares(Smb4KHost *host,
-                 const QList<Smb4KShare *> &shares);
+    void shares(const HostPtr &host);
     
     /**
      * This signal is emitted when an authentication error occurred.
      * 
      * @param host        The host that is affected
      */
-    void authError(Smb4KHost *host,
-                    int process);
+    void authError(const HostPtr &host, int process);
 
     /**
      * This signal is emitted when an IP address was successfully looked
@@ -236,7 +195,7 @@ class Q_DECL_EXPORT Smb4KScanner : public KCompositeJob
      *
      * @param host          The host
      */
-    void ipAddress(Smb4KHost *host);
+    void ipAddress(const HostPtr &host);
 
   protected Q_SLOTS:
     /**
@@ -287,51 +246,57 @@ class Q_DECL_EXPORT Smb4KScanner : public KCompositeJob
      * A lookup process for hosts (domain members) is about to
      * be started
      */
-    void slotAboutToStartHostsLookup(Smb4KWorkgroup *workgroup);
+    void slotAboutToStartHostsLookup(const WorkgroupPtr &workgroup);
 
     /**
      * A lookup process for hosts has finished
      */
-    void slotHostsLookupFinished(Smb4KWorkgroup *workgroup);
+    void slotHostsLookupFinished(const WorkgroupPtr &workgroup);
     
     /**
      * A lookup process for shares is about to be started
      */
-    void slotAboutToStartSharesLookup(Smb4KHost *host);
+    void slotAboutToStartSharesLookup(const HostPtr &host);
 
     /**
      * A lookup process for shares has finished
      */
-    void slotSharesLookupFinished(Smb4KHost *host );
+    void slotSharesLookupFinished(const HostPtr &host);
     
     /**
      * Is called when workgroups and domains have been looked
      * up
      */
-    void slotWorkgroups(const QList<Smb4KWorkgroup *> &workgroups_list);
-
-    /**
-     * Is called when hosts have been looked up by the IP scan method
-     */
-    void slotHosts(const QList<Smb4KHost *> &hosts_list);
+    void slotWorkgroups(const QList<WorkgroupPtr> &workgroups_list);
 
     /**
      * Is called when hosts have been looked up by the normal lookup
      * method
      */
-    void slotHosts(Smb4KWorkgroup *workgroup, const QList<Smb4KHost *> &hosts_list);
+    void slotHosts(const WorkgroupPtr &workgroup, const QList<HostPtr> &hosts_list);
     
     /**
      * Is called when shares have been looked up
      */
-    void slotShares(Smb4KHost *host, const QList<Smb4KShare *> &shares_list);
+    void slotShares(const HostPtr &host, const QList<SharePtr> &shares_list);
     
     /**
      * Is called when an IP address was looked up
      */
-    void slotProcessIPAddress(Smb4KHost *host);
+    void slotProcessIPAddress(const HostPtr &host);
+    
+    /**
+     * This slot is called when the online state changed. It is connected
+     * to the Smb4KHardwareInterface::onlineStateChanged() signal.
+     */
+    void slotOnlineStateChanged(bool online);
 
   private:
+    /**
+     * Start the scanning of the network neighborhood
+     */
+    void startScanning();
+    
     /**
      * Pointer to Smb4KScannerPrivate class
      */
