@@ -2,7 +2,7 @@
     Smb4K's container class for information about a share.
                              -------------------
     begin                : Mo Jan 28 2008
-    copyright            : (C) 2008-2016 by Alexander Reinholdt
+    copyright            : (C) 2008-2017 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -325,9 +325,9 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
     void setInaccessible(bool in);
 
     /**
-     * Returns TRUE if the share is not accessible by the user and FALSE otherwise.
+     * Returns TRUE if the share is mounted and not accessible by the user.
      *
-     * @returns TRUE if the share is inaccessible.
+     * @returns TRUE if the share is mounted and inaccessible.
      */
     bool isInaccessible() const;
 
@@ -341,7 +341,7 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
     void setForeign(bool foreign);
 
     /**
-     * Returns TRUE if the share was mounted and is owned by another user.
+     * Returns TRUE if the share is mounted and is owned by another user.
      *
      * @returns TRUE if this is a foreign share.
      */
@@ -618,6 +618,14 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      */
     QString password() const;
     
+    /**
+     * Updates the share item if the workgroup name and the UNC of @p share and
+     * of this item is equal. Otherwise it does nothing.
+     * @param share           The share object that is used to update
+     *                        this object
+     */
+    void update(Smb4KShare *share);
+    
   private:
     /**
      * Set up the shares icon.
